﻿//----------------------------------------------------
// SteelSection.cs (c) 2019 by Enes Siljak
//----------------------------------------------------

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Autodesk.AdvanceSteel.CADAccess;
using Autodesk.AdvanceSteel.CADLink.Database;
using Autodesk.AdvanceSteel.ConstructionHelper;
using Autodesk.AdvanceSteel.ConstructionTypes;
using Autodesk.AdvanceSteel.DocumentManagement;
using Autodesk.AdvanceSteel.Geometry;
using Autodesk.AdvanceSteel.Modelling;
using Autodesk.AdvanceSteel.Profiles;
using Autodesk.AdvanceSteel.Runtime;
using Autodesk.AutoCAD.ApplicationServices;
using Autodesk.AutoCAD.DatabaseServices;
using Autodesk.AutoCAD.EditorInput;

namespace AsCreateStructure
{
    enum STEELSECTYPE
    {   HEA, HEB, IPE, 
        UPE,
        L, L_UNEQUAL, 
        SHS,
        RHS,
        CHS
    }

    enum INSERTION_POINT
    {
        BOTTOM_LEFT,
        BOTTOM_CENTER,
        BOTTOM_RIGHT,
        MIDDLE_LEFT,
        MIDDLE_CENTER,
        MIDDLE_RIGHT,
        TOP_LEFT,
        TOP_CENTER,
        TOP_RIGHT,
        CENTROID,
        SHEAR_CENTER
    }

    class SteelSection
    {
        STEELSECTYPE type;
        string secID = "";
        INSERTION_POINT insertionPoint;
        double y_offset = 0;
        double z_offset = 0;
        string material = "";
        string label = "";

        public  SteelSection(STEELSECTYPE type, string secIndex, string material, 
            INSERTION_POINT insertionPoint, double y_offset, double z_offset, string label)
        {
            this.type = type;
            this.secID = secIndex;
            this.material = material;

            /*
             *alignement of beam to be finished 
             */
            this.insertionPoint = insertionPoint;
            this.y_offset = y_offset;
            this.z_offset = z_offset;
            this.label = label;

        }

        override public string ToString()
        {
            StringBuilder sb = new StringBuilder();
            sb.AppendFormat("\nSTEEL SECTION LABEL :{0}:", label);
            sb.AppendFormat("\nTYPE                :{0}:", type);
            sb.AppendFormat("\nSECTION             :{0}:", secID);
            sb.AppendFormat("\nMATERIAL            :{0}:", material);
            sb.AppendFormat("\nINSERTION POINT     :{0}:", insertionPoint);
            sb.AppendFormat("\nY OFFSET            :{0}:", y_offset);
            sb.AppendFormat("\nZ OFFSET            :{0}:", z_offset);
            sb.Append("\nEND SECTION");
            
            return sb.ToString();
        }

        public string getProfileName()
        {
            string database = "IPE  DIN18800-1";
            string record = "IPE80";

            string result = getPName(database, record);

            switch (type)
            {
                case STEELSECTYPE.HEA:
                    result = getPName("HEA  DIN18800-1", secID);
                    break;
                case STEELSECTYPE.HEB:
                    result = getPName("HEB  DIN18800-1", secID);
                    break;
                case STEELSECTYPE.IPE:
                    result = getPName("IPE  DIN18800-1", secID);
                    break;

                case STEELSECTYPE.UPE:
                    result = getPName("UPE", secID);
                    break;

                case STEELSECTYPE.L:
                    result = getPName("Angle_eq DIN18800-1", secID);
                    break;
                case STEELSECTYPE.L_UNEQUAL:
                    result = getPName("Angle_uneq DIN18800-1", secID);
                    break;

                case STEELSECTYPE.SHS:
                    result = getPName("RHS_Sections_square_w nach DIN", secID);
                    break;

                case STEELSECTYPE.RHS:
                    result = getPName("RHS_Sections_rectang_w nach DIN", secID);
                    break;
                case STEELSECTYPE.CHS:
                    result = getPName("Pipe nach DIN", secID);
                    break;
            }

            return result;
        }

        private string getPName(string database, string record)
        {
            return string.Format("{0}#@§@#{1}", database, record); 
        }

        public string getMaterial()
        {
            return material;
        }
    }
}
